==> hubzero-submit-distributor_1.0.0.orig.tar.gz: hubzero-submit-distributor-1.0.0/Scripts/condor/transmitresults.sh <==
#!/bin/sh
#
# @package      hubzero-submit-distributor
# @file         Scripts/condor/transmitresults.sh
# @author       Steve Clark <clarks@purdue.edu>
# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2011 Purdue University
# All rights reserved.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of Purdue University.
#
if [ $# -ne 1 ] ; then
   echo usage: $0 jobWorkingDirectory
   exit 64
fi

cd $1
exitStatus=$?

if [ $exitStatus -eq 0 ] ; then
# Allow for file/directory names with embedded spaces.
   find . -newer .__fileTimeMarker -not -name . -print0 | xargs --null tar czf -
   exitStatus=$?
fi

exit $exitStatus

==> hubzero-submit-distributor_2.5.6.orig.tar.gz: hubzero-submit-distributor-2.5.6/Scripts/condor/transmitresults.sh <==
#!/bin/sh
#
# @package      hubzero-submit-distributor
# @file         Scripts/condor/transmitresults.sh
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright 2004-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
if [ $# -ne 1 ] ; then
   echo usage: $0 jobWorkingDirectory
   exit 64
fi

jobWorkingDirectory=$1

cd ${jobWorkingDirectory}
exitStatus=$?

if [ ${exitStatus} -eq 0 ] ; then
# Allow for file/directory names with embedded spaces.
   find . -newer .__fileTimeMarker -not -name . -print0 | xargs --null tar czf -
   exitStatus=$?
fi

exit ${exitStatus}
